# Installation

CauliFlow requires Python 3.11 or higher.

To install CauliFlow with `pip`, run the following command:

```bash
pip install cauliflow
```

To confirm that the installation was successful, run:

```bash
cauliflow --version
```

You should see an output like the following:

```bash
cauliflow 0.1.0
```
